summaryrefslogtreecommitdiff
path: root/libopie
authordrw <drw>2002-04-30 01:09:14 (UTC)
committer drw <drw>2002-04-30 01:09:14 (UTC)
commited745f7e21eb32fbf5d9a3f1734d79b25cfa629c (patch) (side-by-side diff)
treeb91b936b12d1d25a813858b76a62e023d8ac2d23 /libopie
parentb794af4c50efffe239c94e5a015e90565ff991c3 (diff)
downloadopie-ed745f7e21eb32fbf5d9a3f1734d79b25cfa629c.zip
opie-ed745f7e21eb32fbf5d9a3f1734d79b25cfa629c.tar.gz
opie-ed745f7e21eb32fbf5d9a3f1734d79b25cfa629c.tar.bz2
Renamed QColorDialog to OColorDialog
Diffstat (limited to 'libopie') (more/less context) (ignore whitespace changes)
-rw-r--r--libopie/colordialog.cpp56
-rw-r--r--libopie/colordialog.h22
-rw-r--r--libopie/colorpopupmenu.cpp2
3 files changed, 40 insertions, 40 deletions
diff --git a/libopie/colorpopupmenu.cpp b/libopie/colorpopupmenu.cpp
index 35e91f4..9b50a8b 100644
--- a/libopie/colorpopupmenu.cpp
+++ b/libopie/colorpopupmenu.cpp
@@ -160,3 +160,3 @@ void ColorPopupMenu::moreColorClicked()
{
- QColor color = QColorDialog::getColor( m_color );
+ QColor color = OColorDialog::getColor( m_color );
m_color = color;
diff --git a/libopie/colordialog.cpp b/libopie/colordialog.cpp
index 6d72ff6..684d6ea 100644
--- a/libopie/colordialog.cpp
+++ b/libopie/colordialog.cpp
@@ -3,3 +3,3 @@
**
** Implementation of QColorDialog class
**
@@ -478,3 +478,3 @@ QColorShower::QColorShower( QWidget *parent, const char *name )
hEd->setValidator( val360 );
- QLabel *l = new QLabel( hEd, QColorDialog::tr("Hue:"), this );
+ QLabel *l = new QLabel( hEd, OColorDialog::tr("Hue:"), this );
l->setAlignment( AlignRight|AlignVCenter );
@@ -485,3 +485,3 @@ QColorShower::QColorShower( QWidget *parent, const char *name )
sEd->setValidator( val256 );
- l = new QLabel( sEd, QColorDialog::tr("Sat:"), this );
+ l = new QLabel( sEd, OColorDialog::tr("Sat:"), this );
l->setAlignment( AlignRight|AlignVCenter );
@@ -492,3 +492,3 @@ QColorShower::QColorShower( QWidget *parent, const char *name )
vEd->setValidator( val256 );
- l = new QLabel( vEd, QColorDialog::tr("Val:"), this );
+ l = new QLabel( vEd, OColorDialog::tr("Val:"), this );
l->setAlignment( AlignRight|AlignVCenter );
@@ -499,3 +499,3 @@ QColorShower::QColorShower( QWidget *parent, const char *name )
rEd->setValidator( val256 );
- l = new QLabel( rEd, QColorDialog::tr("Red:"), this );
+ l = new QLabel( rEd, OColorDialog::tr("Red:"), this );
l->setAlignment( AlignRight|AlignVCenter );
@@ -506,3 +506,3 @@ QColorShower::QColorShower( QWidget *parent, const char *name )
gEd->setValidator( val256 );
- l = new QLabel( gEd, QColorDialog::tr("Green:"), this );
+ l = new QLabel( gEd, OColorDialog::tr("Green:"), this );
l->setAlignment( AlignRight|AlignVCenter );
@@ -513,3 +513,3 @@ QColorShower::QColorShower( QWidget *parent, const char *name )
bEd->setValidator( val256 );
- l = new QLabel( bEd, QColorDialog::tr("Blue:"), this );
+ l = new QLabel( bEd, OColorDialog::tr("Blue:"), this );
l->setAlignment( AlignRight|AlignVCenter );
@@ -520,3 +520,3 @@ QColorShower::QColorShower( QWidget *parent, const char *name )
alphaEd->setValidator( val256 );
- alphaLab = new QLabel( alphaEd, QColorDialog::tr("Alpha channel:"), this );
+ alphaLab = new QLabel( alphaEd, OColorDialog::tr("Alpha channel:"), this );
alphaLab->setAlignment( AlignRight|AlignVCenter );
@@ -609,3 +609,3 @@ void QColorShower::setHsv( int h, int s, int v )
-class QColorDialogPrivate : public QObject
+class OColorDialogPrivate : public QObject
{
@@ -613,3 +613,3 @@ Q_OBJECT
public:
- QColorDialogPrivate( QColorDialog *p );
+ OColorDialogPrivate( OColorDialog *p );
QRgb currentColor() const { return cs->currentColor(); }
@@ -631,3 +631,3 @@ private:
//sets all widgets to display h,s,v
-void QColorDialogPrivate::newHsv( int h, int s, int v )
+void OColorDialogPrivate::newHsv( int h, int s, int v )
{
@@ -639,3 +639,3 @@ void QColorDialogPrivate::newHsv( int h, int s, int v )
//sets all widgets to display rgb
-void QColorDialogPrivate::setCurrentColor( QRgb rgb )
+void OColorDialogPrivate::setCurrentColor( QRgb rgb )
{
@@ -646,3 +646,3 @@ void QColorDialogPrivate::setCurrentColor( QRgb rgb )
//sets all widgets exept cs to display rgb
-void QColorDialogPrivate::newColorTypedIn( QRgb rgb )
+void OColorDialogPrivate::newColorTypedIn( QRgb rgb )
{
@@ -654,3 +654,3 @@ void QColorDialogPrivate::newColorTypedIn( QRgb rgb )
-QColorDialogPrivate::QColorDialogPrivate( QColorDialog *dialog ) :
+OColorDialogPrivate::OColorDialogPrivate( OColorDialog *dialog ) :
QObject(dialog)
@@ -687,4 +687,4 @@ QColorDialogPrivate::QColorDialogPrivate( QColorDialog *dialog ) :
/*!
- \class QColorDialog qcolordialog.h
- \brief The QColorDialog class provides a dialog widget for specifying colors.
+ \class OColorDialog OColorDialog.h
+ \brief The OColorDialog class provides a dialog widget for specifying colors.
\ingroup dialogs
@@ -714,6 +714,6 @@ QColorDialogPrivate::QColorDialogPrivate( QColorDialog *dialog ) :
-QColorDialog::QColorDialog(QWidget* parent, const char* name, bool modal) :
+OColorDialog::OColorDialog(QWidget* parent, const char* name, bool modal) :
QDialog(parent, name, modal )
{
- d = new QColorDialogPrivate( this );
+ d = new OColorDialogPrivate( this );
}
@@ -728,3 +728,3 @@ QColorDialog::QColorDialog(QWidget* parent, const char* name, bool modal) :
-QColor QColorDialog::getColor( QColor initial, QWidget *parent,
+QColor OColorDialog::getColor( QColor initial, QWidget *parent,
const char *name )
@@ -732,3 +732,3 @@ QColor QColorDialog::getColor( QColor initial, QWidget *parent,
int allocContext = QColor::enterAllocContext();
- QColorDialog *dlg = new QColorDialog( parent, name, TRUE ); //modal
+ OColorDialog *dlg = new OColorDialog( parent, name, TRUE ); //modal
if ( parent && parent->icon() && !parent->icon()->isNull() )
@@ -738,3 +738,3 @@ QColor QColorDialog::getColor( QColor initial, QWidget *parent,
- dlg->setCaption( QColorDialog::tr( "Select color" ) );
+ dlg->setCaption( OColorDialog::tr( "Select color" ) );
dlg->setColor( initial );
@@ -765,3 +765,3 @@ QColor QColorDialog::getColor( QColor initial, QWidget *parent,
-QRgb QColorDialog::getRgba( QRgb initial, bool *ok,
+QRgb OColorDialog::getRgba( QRgb initial, bool *ok,
QWidget *parent, const char* name )
@@ -769,3 +769,3 @@ QRgb QColorDialog::getRgba( QRgb initial, bool *ok,
int allocContext = QColor::enterAllocContext();
- QColorDialog *dlg = new QColorDialog( parent, name, TRUE ); //modal
+ OColorDialog *dlg = new OColorDialog( parent, name, TRUE ); //modal
dlg->setColor( initial );
@@ -799,3 +799,3 @@ QRgb QColorDialog::getRgba( QRgb initial, bool *ok,
-QColor QColorDialog::color() const
+QColor OColorDialog::color() const
{
@@ -809,3 +809,3 @@ QColor QColorDialog::color() const
-QColorDialog::~QColorDialog()
+OColorDialog::~OColorDialog()
{
@@ -821,3 +821,3 @@ QColorDialog::~QColorDialog()
-void QColorDialog::setColor( QColor c )
+void OColorDialog::setColor( QColor c )
{
@@ -834,3 +834,3 @@ void QColorDialog::setColor( QColor c )
-void QColorDialog::setSelectedAlpha( int a )
+void OColorDialog::setSelectedAlpha( int a )
{
@@ -845,3 +845,3 @@ void QColorDialog::setSelectedAlpha( int a )
-int QColorDialog::selectedAlpha() const
+int OColorDialog::selectedAlpha() const
{
@@ -3,3 +3,3 @@
**
-** Implementation of QColorDialog class
+** Implementation of OColorDialog class
**
diff --git a/libopie/colordialog.h b/libopie/colordialog.h
index a2d4d30..474bc61 100644
--- a/libopie/colordialog.h
+++ b/libopie/colordialog.h
@@ -3,3 +3,3 @@
**
** Definition of QColorDialog class
**
@@ -37,4 +37,4 @@
-#ifndef QCOLORDIALOG_H
-#define QCOLORDIALOG_H
+#ifndef OColorDialog_H
+#define OColorDialog_H
@@ -44,5 +44,5 @@
-class QColorDialogPrivate;
+class OColorDialogPrivate;
-class Q_EXPORT QColorDialog : public QDialog
+class Q_EXPORT OColorDialog : public QDialog
{
@@ -56,5 +56,5 @@ public:
private:
- ~QColorDialog();
+ ~OColorDialog();
- QColorDialog( QWidget* parent=0, const char* name=0, bool modal=FALSE );
+ OColorDialog( QWidget* parent=0, const char* name=0, bool modal=FALSE );
void setColor( QColor ); // ### 3.0: make const QColor&
@@ -66,4 +66,4 @@ private:
private:
- QColorDialogPrivate *d;
- friend class QColorDialogPrivate;
+ OColorDialogPrivate *d;
+ friend class OColorDialogPrivate;
@@ -71,4 +71,4 @@ private: // Disabled copy constructor and operator=
#if defined(Q_DISABLE_COPY)
- QColorDialog( const QColorDialog & );
- QColorDialog& operator=( const QColorDialog & );
+ OColorDialog( const OColorDialog & );
+ OColorDialog& operator=( const OColorDialog & );
#endif
@@ -3,3 +3,3 @@
**
-** Definition of QColorDialog class
+** Definition of OColorDialog class
**